﻿using Infragistics.Controls.Editors;
using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Input;

namespace XNRSCommandBinding.ViewModel
{
    class ViewModel : INotifyPropertyChanged
    {
        private double _value1;
        private double _value2;
        private double _rangeSpan;

        private ICommand _calculateRangeSpanCommand;

        public ViewModel()
        { 
            this.Value1 = 10;
            this.Value2 = 90;
            this.RangeSpan = Math.Abs(Value2 - Value1);
            this.CalculateRangeSpanCommand = new RelayCommand(param => CalculateRangeSpanCommandMethod(param), param => true);
        }

        public double Value1
        {
            get { return _value1; }
            set
            {
                if (_value1 != value)
                {
                    _value1 = value;
                    NotifyPropertyChanged("Value1");
                }
            }
        }

        public double Value2
        {
            get { return _value2; }
            set
            {
                if (_value2 != value)
                {
                    _value2 = value;
                    NotifyPropertyChanged("Value2");
                }
            }
        }

        public double RangeSpan
        {
            get { return _rangeSpan; }
            set
            {
                if (_rangeSpan != value)
                {
                    _rangeSpan = value;
                    NotifyPropertyChanged("RangeSpan");
                }
            }
        }

        public ICommand CalculateRangeSpanCommand
        {
            get { return _calculateRangeSpanCommand; }
            set
            {
                _calculateRangeSpanCommand = value;
            }
        }

        public void CalculateRangeSpanCommandMethod(object parameter)
        {
            if(parameter != null)
            {
                ObservableCollection<XamSliderThumb<Double>> Thumbs = parameter as ObservableCollection<XamSliderThumb<Double>>;
                RangeSpan = Math.Abs(Thumbs[1].Value - Thumbs[0].Value);
            }
        }

        #region Notify Property Changed.

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }

        #endregion
    }
  
}
